@@ -2,27 +2,34 @@ import hashlib
 
 from sqlalchemy import (
     Column,
-    BigInteger,
     DateTime,
     Unicode,
     ForeignKey,
 )
+from sqlalchemy.types import (
+    Integer,
+)
 
 from sqlalchemy.ext.declarative import declarative_base
 
 from sqlalchemy.orm import (
+    scoped_session,
     sessionmaker,
     relationship,
     backref,
 )
 
 
+from zope.sqlalchemy import ZopeTransactionExtension
+
+DBSession = scoped_session(sessionmaker(extension=ZopeTransactionExtension()))
 DeclarativeBase = declarative_base()
+DeclarativeBase.query = DBSession.query_property()
 
 
 class Issuer(DeclarativeBase):
     __tablename__ = 'issuers'
-    id = Column(BigInteger, primary_key=True)
+    id = Column(Integer, unique=True, primary_key=True)
     origin = Column(Unicode(128), nullable=False)
     name = Column(Unicode(128), nullable=False, unique=True)
     org = Column(Unicode(128), nullable=False)
@@ -53,7 +60,7 @@ class Badge(DeclarativeBase):
     description = Column(Unicode(128), nullable=False)
     criteria = Column(Unicode(128), nullable=False)
     assertions = relationship("Assertion", backref="badge")
-    issuer_id = Column(BigInteger, ForeignKey('issuers.id'), nullable=False)
+    issuer_id = Column(Integer, ForeignKey('issuers.id'), nullable=False)
 
     def __unicode__(self):
         return self.name
@@ -71,7 +78,7 @@ class Badge(DeclarativeBase):
 
 class Person(DeclarativeBase):
     __tablename__ = 'persons'
-    id = Column(BigInteger, primary_key=True)
+    id = Column(Integer, unique=True, primary_key=True)
     email = Column(Unicode(128), nullable=False, unique=True)
     assertions = relationship("Assertion", backref="person")
 
@@ -116,7 +123,7 @@ class Assertion(DeclarativeBase):
     id = Column(Unicode(128), primary_key=True, unique=True,
                 default=assertion_id_default)
     badge_id = Column(Unicode(128), ForeignKey('badges.id'), nullable=False)
-    person_id = Column(BigInteger, ForeignKey('persons.id'), nullable=False)
+    person_id = Column(Integer, ForeignKey('persons.id'), nullable=False)
     salt = Column(Unicode(128), nullable=False, default=salt_default)
     issued_on = Column(DateTime)
 
